@@ -38,11 +38,13 @@
 /*	Terminate the master process after \fIexit_time\fR seconds. Child
 /*	processes terminate at their convenience.
 /* .IP \fB-i\fR
-/*	Enable \fBinit\fR mode: do not attempt to become a session
-/*	or process group leader; and to force termination, set an
-/*	explicit signal handler instead of relying on the default
-/*	signal action. This mode is allowed only if the process ID
-/*	equals 1.
+/*	Enable \fBinit\fR mode: do not become a session or process
+/*	group leader; similar to \fB-s\fR, do not redirect stdout
+/*	to /dev/null, so that "maillog_file = /dev/stdout" works.
+/*	This mode is allowed only if the process ID equals 1.
+/* .IP \fB-s\fR
+/*	Do not redirect stdout to /dev/null, so that "maillog_file
+/*	= /dev/stdout" works.
 /* .IP \fB-t\fR
 /*	Test mode. Return a zero exit status when the \fBmaster.pid\fR lock
 /*	file does not exist or when that file is not locked.  This is evidence
@@ -263,6 +265,7 @@ int     main(int argc, char **argv)
     VSTRING *data_lock_path;
     off_t   inherited_limit;
     int     debug_me = 0;
+    int     keep_stdout = 0;
     int     ch;
     int     fd;
     int     n;
@@ -341,7 +344,7 @@ int     main(int argc, char **argv)
     /*
      * Process JCL.
      */
-    while ((ch = GETOPT(argc, argv, "c:Dde:itvw")) > 0) {
+    while ((ch = GETOPT(argc, argv, "c:Dde:istvw")) > 0) {
 	switch (ch) {
 	case 'c':
 	    if (setenv(CONF_ENV_PATH, optarg, 1) < 0)
@@ -357,9 +360,13 @@ int     main(int argc, char **argv)
 	    if (getpid() != 1)
 		msg_fatal("-i is allowed only for PID 1 process");
 	    init_mode = 1;
+	    keep_stdout = 1;
 	    break;
 	case 'D':
-	    debug_me = 1;
+            debug_me = 1;
+	    break;
+	case 's':
+	    keep_stdout = 1;
 	    break;
 	case 't':
 	    test_lock = 1;
@@ -407,6 +414,8 @@ int     main(int argc, char **argv)
      */
     if (master_detach)
 	for (fd = 0; fd < 3; fd++) {
+	    if (fd == STDOUT_FILENO && keep_stdout)
+		continue;
 	    (void) close(fd);
 	    if (open("/dev/null", O_RDWR, 0) != fd)
 		msg_fatal("open /dev/null: %m");
